pub struct HydraBitNet { /* private fields */ }Expand description
Complete Hydra model
Implementations
Sourceimpl HydraBitNet
impl HydraBitNet
Sourcepub fn config(&self) -> &HydraConfig
pub fn config(&self) -> &HydraConfig
Get model configuration
Sourcepub fn predict_compression(&self, token_ids: &[u32]) -> Array1<f32>
pub fn predict_compression(&self, token_ids: &[u32]) -> Array1<f32>
Forward pass for compression prediction Returns probabilities for [NONE, BPE, BROTLI, ZLIB]
Sourcepub fn predict_security(&self, token_ids: &[u32]) -> Array1<f32>
pub fn predict_security(&self, token_ids: &[u32]) -> Array1<f32>
Forward pass for security prediction Returns probabilities for [SAFE, UNSAFE]